# Copyright (c) 2025 Microsoft Corporation.
"""Prompts for activity-local generation in AutoQ."""

LOCAL_GENERAION_SYSTEM_PROMPT = """\
---ROLE---
You are a helpful assistant tasked with identifying activity-related questions targeting key entities in a dataset.

---INPUT---
You will be provided with the following information:

- Persona: a description of a persona interested in the dataset.
- Task: a task that the persona might want to perform using the dataset.
- Entities: a list of key entities extracted from the dataset that might be relevant to the persona's task.

---TASK---
Generate a set of questions that are relevant to the persona's task and the provided entities.

---INSTRUCTIONS---
Each question should:
- make a clear reference to the selected entities and the persona's target task;
- be relevant to the persona's task and can be entirely and accurately answered based on the selected entity descriptions, rather than requiring external knowledge;
- avoid telegraphing the answer to the question. For example, consider this question: "Given the recent incidents in Zanzibar, what are the health implications of consuming sea turtle meat that have resulted in multiple deaths and hospitalizations?". This is a BAD output question because it telegraphs the answer by mentioning the deaths and hospitalizations as a result of consuming sea turtle meat;
- stand alone in the absence of the entities and other questions;
- be short and concise;
- ask only one thing at a time rather than having multiple sub-questions. For example, this question is BAD because it has multiple sub-questions: ""What recent tragic incidents related to the fentanyl crisis have occurred in Washington and Oregon, and what measures are officials taking in response to these events?";
- Fully describe all references to people, places, or things. Such references should only be included if including this information materially affects the answer.
Ensure that ALL references are clear and unambiguous, e.g., don't refer to "the <entity>", but refer to named or described entities in ways that distinguish them from all other <entities>.
Do this for ALL references, and ensure that all references are absolute (e.g., summer 2024) rather than relative (e.g., this summer).
Examples:

"the proposal" -> "the proposal of the governor of California to increase funding for public schools"
"the meeting" -> "the meeting of Contoso with their new client to discuss the upcoming project"
"the president" -> "the president of the company, John Doe"

Question set should be distinct, diverse and cover different aspects of the entities and the task. Avoid repetitive questions.


---OUTPUT---
Use the following JSON object structure:
{{
    "questions": [
        {{
            "entities": ["A list of one or more entities from the list of provided entities that the question is focused on. Format each entity as entity_name: entity_description"],
            "output_question": "A concrete question that is relevant to the persona's task and can be answered based on the selected entity descriptions. Frame each question in a way that makes a clear reference to the selected entities and the persona's target task, without telegraphing the answer to the question. Keep the question short and concise. The question should ask only one thing at a time rather than having multiple sub-questions",
        }},
        ...
    ]
}}

Output JSON only, with no additional text or commentary. Aims for {num_questions} concrete questions.
"""

LOCAL_GENERAION_USER_PROMPT = """\
---Persona---
{persona}

---Task of interest---
{task}

---Entities---
{entity_description}

---Number of questions to generate---
{num_questions}

---OUTPUT---
Outputthe following JSON object structure:
{{
    "questions": [
        {{
            "entities": ["A list of one or more entities from the list of provided entities that the question is focused on. Format each entity as entity_name: entity_description"],
            "output_question": "A concrete question that is relevant to the persona's task and can be answered based on the selected entity descriptions.",
        }},
        ...
    ]
}}
"""
